<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Circle3P</name>
    <message>
        <location filename="../Circle3P.js" line="+63"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation>Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Third point</source>
        <translatorcomment>--google--
Wskaż trzeci punkt</translatorcomment>
        <translation>Trzeci punkt</translation>
    </message>
    <message>
        <location filename="../Circle3PInit.js" line="+2"/>
        <source>&amp;3 Points</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;3 Punkty</translatorcomment>
        <translation>&amp;3 punkty</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle from 3 points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje okrąg przez 3 punkty</translation>
    </message>
</context>
</TS>
